@@ -8,7 +8,9 @@
 import os
 import logging
 import fnmatch
+import glob
 from typing import Iterable
+from pathlib import Path
 
 #
 # Class to help convert from absolute path to EDK2 build path
@@ -63,50 +65,45 @@ class Edk2Path(object):
         if(error and error_on_invalid_pp):
             raise Exception("Invalid package path directory(s)")
 
+        # for each package path, trace from packagepath to the
+        # either the workspace root or filesystem root and verify
+        # no *.DEC file exists. This would signify a nested package.
+        for package_path in self.PackagePathList:
+            p = Path(package_path)
+            ws = self.WorkspacePath
+            while p != p.parent:
+                if str(p).lower() == str(ws).lower():
+                    break
+                if len(glob.glob(f'{p}/*dec')) != 0:
+                    raise Exception(f'Nested packages not allowed. Pkg path [{package_path}] nested in Package [{p}]')
+                p = p.parent
+
     def GetEdk2RelativePathFromAbsolutePath(self, abspath):
         ''' Given an absolute path return a edk2 path relative
         to workspace or packagespath.
 
         If not valid return None
         '''
-
-        relpath = None
-        found = False
         if abspath is None:
             return None
-        for a in (os.path.normcase(p) for p in self.PackagePathList):
-            a = a if a.endswith(os.sep) else a + os.sep  # add sep if no trailing separater
 
-            # iterate over a normalized case of packages path including trailing separater
-            # to ensure match is of full directory path.
-            if os.path.normcase(abspath).startswith(a):
-                # found our path...now use original strings to avoid
-                # change in case
-                relpath = abspath[len(a):]
-                found = True
-                self.logger.debug("Successfully converted AbsPath to Edk2Relative Path using PackagePath")
-                self.logger.debug("AbsolutePath: %s found in PackagePath: %s" % (abspath, a))
-                break
+        # Path does not need to exist; therefore find the first parent
+        # directory that exists and use that to generate the relative path.
+        temp_path = Path(abspath)
+        while not temp_path.exists():
+            if temp_path is temp_path.parent:
+                return None
+            temp_path = temp_path.parent
 
-        if(not found):
-            # Does path start with workspace path
-            wsp = self.WorkspacePath if self.WorkspacePath.endswith(os.sep) else self.WorkspacePath + os.sep
-            if os.path.normcase(abspath).startswith(os.path.normcase(wsp)):
-                # found our path...now use original strings to avoid
-                # change in case
-                relpath = abspath[len(wsp):]
-                found = True
-                self.logger.debug("Successfully converted AbsPath to Edk2Relative Path using WorkspacePath")
-                self.logger.debug("AbsolutePath: %s found in Workspace: %s" % (abspath, self.WorkspacePath))
-
-        if(found):
+        package = self.GetContainingPackage(abspath)
+        if package is not None:
+            relpath = abspath[str(temp_path).find(package):]
             relpath = relpath.replace(os.sep, "/")
             return relpath.lstrip("/")
-
-        # didn't find the path for conversion.
-        self.logger.error("Failed to convert AbsPath to Edk2Relative Path")
-        self.logger.error("AbsolutePath: %s" % abspath)
-        return None
+        else:
+            self.logger.error("Failed to convert AbsPath to Edk2Relative Path")
+            self.logger.error("AbsolutePath: %s" % abspath)
+            return None
 
     def GetAbsolutePathOnThisSystemFromEdk2RelativePath(self, relpath, log_errors=True):
         ''' Given a edk2 relative path return an absolute path to the file
