@@ -167,11 +167,14 @@ def timing(f):
 #                                     return code is not zero.
 # @param encodingErrors - may be given to set the desired error handling for encoding errors decoding cmd output.
 #                         Default is 'strict'.
+# @param close_fds - If True, file descriptors are closed before the command is run.
+#                    Default is True.
 #
 # @return returncode of called cmd
 ####
 def RunCmd(cmd, parameters, capture=True, workingdir=None, outfile=None, outstream=None, environ=None,
-           logging_level=logging.INFO, raise_exception_on_nonzero=False, encodingErrors='strict'):
+           logging_level=logging.INFO, raise_exception_on_nonzero=False, encodingErrors='strict',
+           close_fds=True):
     cmd = cmd.strip('"\'')
     if " " in cmd:
         cmd = '"' + cmd + '"'
@@ -183,7 +186,8 @@ def RunCmd(cmd, parameters, capture=True, workingdir=None, outfile=None, outstre
     logging.log(logging_level, "------------------------------------------------")
     logging.log(logging_level, "--------------Cmd Output Starting---------------")
     logging.log(logging_level, "------------------------------------------------")
-    c = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, cwd=workingdir, shell=True, env=environ)
+    c = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT,
+                         cwd=workingdir, shell=True, env=environ, close_fds=close_fds)
     if(capture):
         thread = PropagatingThread(target=reader, args=(outfile, outstream, c.stdout, logging_level, encodingErrors))
         thread.start()
